# *EduTK*: a toolkit to create modern programming exercises (*Python* version)

[![license: MIT](https://img.shields.io/github/license/epeios-q37/edutk-python?color=yellow&style=for-the-badge)](https://github.com/epeios-q37/edutk-python/blob/master/LICENSE) [![Version](https://img.shields.io/pypi/v/edutk?style=for-the-badge&color=90b4ed&label=PyPi)](http://q37.info/s/xhgwkn7v)


The purpose of this toolkit is to provide the simplest possible way to create modern programming exercises, i.e. exercises:
- fitted with a graphical interface,
- easily accessible from mobile devices like smartphones.

For more details and some examples, see <https://q37.info/s/cbms43s9>.

---

This project is based on the [*Atlas* toolkit](https://atlastk.org). Other projects using this toolkit can be found here: <https://q37.info/s/sssznrb4>.
